#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 comonad
version:              5.0.8
visibility:           public
id:                   comonad-5.0.8-8a10YHmXJVq2BoDg3RtKOL
key:                  comonad-5.0.8-8a10YHmXJVq2BoDg3RtKOL
license:              BSD-3-Clause
copyright:
    Copyright (C) 2008-2014 Edward A. Kmett,
    Copyright (C) 2004-2008 Dave Menendez

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/comonad/
synopsis:             Comonads
description:          Comonads.
category:             Control, Comonads
abi:                  469ee03e86cfaffea159f77b2272b12d
exposed:              True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition

import-dirs:          /usr/lib/ghc-8.10.5/site-local/comonad-5.0.8
library-dirs:         /usr/lib/ghc-8.10.5/site-local/comonad-5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/comonad-5.0.8
hs-libraries:         HScomonad-5.0.8-8a10YHmXJVq2BoDg3RtKOL
depends:
    base-4.14.2.0 containers-0.6.4.1
    distributive-0.6.2.1-FKGYrCjdfe8EPx7TggrhZc
    indexed-traversable-0.1.1-1Z2GfU1EWlL3ZzMnGNHsA4
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk

haddock-interfaces:   /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html:         /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

